import logging
import time
from kubemq.pubsub import *

def main():

    try:
        client = Client(address="localhost:50000", client_id="events_example")
        def on_receive_event(event: EventMessageReceived):
            print(
                f"Id:{event.id}, Timestamp:{event.timestamp} From: {event.from_client_id},  Body:{event.body.decode('utf-8')}")

        def on_error_handler(err: str):
            print(f"{err}")

        client.subscribe_to_events(
            subscription=EventsSubscription(
                channel="e1",
                group="",
                on_receive_event_callback=on_receive_event,
                on_error_callback=on_error_handler,
            )
            , cancel=CancellationToken())
        time.sleep(1)
        client.send_events_message(EventMessage(
            channel="e1",
            body=b"hello kubemq"
        ))
        time.sleep(1)
    except Exception as e:
        print(e)
        return


if __name__ == "__main__":
    main()



import pathlib
from setuptools import setup, find_packages  # Corrected import statement

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name='kubemq',
    version='3.0.0',
    description='KubeMQ SDK for Python',
    long_description=README,
    long_description_content_type="text/markdown",
    url='https://github.com/kubemq-io/kubemq-Python',
    author='KubeMQ',
    author_email='info@kubemq.io',
    license='MIT',
    packages=find_packages(),  # Corrected function call
    install_requires=[
        'grpcio>=1.51.1',
        'protobuf>=4.21.0',
        'setuptools>=40.8.0',
        'PyJWT>=2.6.0',
    ],
    zip_safe=False
)
